@@ -1,8 +1,8 @@
-;;; evil-core.el --- Core functionality
+;;; evil-core.el --- Core functionality -*- lexical-binding: t -*-
 ;; Author: Vegard Øye <vegard_oye at hotmail.com>
 ;; Maintainer: Vegard Øye <vegard_oye at hotmail.com>
 
-;; Version: 1.12.17
+;; Version: 1.14.0
 
 ;;
 ;; This file is NOT part of GNU Emacs.
@@ -381,6 +381,8 @@ then this function does nothing."
 (defun evil-generate-mode-line-tag (&optional state)
   "Generate the evil mode-line tag for STATE."
   (let ((tag (evil-state-property state :tag t)))
+    (when (functionp tag)
+      (setq tag (funcall tag)))
     ;; prepare mode-line: add tooltip
     (if (stringp tag)
         (propertize tag
@@ -479,8 +481,7 @@ This allows input methods to be used in normal-state."
   "Initialize a buffer-local value for local keymaps as necessary.
 The initial value is that of `make-sparse-keymap'."
   (dolist (entry evil-local-keymaps-alist)
-    (let ((mode (car entry))
-          (map  (cdr entry)))
+    (let ((map  (cdr entry)))
       (unless (and (keymapp (symbol-value map))
                    (local-variable-p map))
         (set map (make-sparse-keymap))))))
@@ -568,11 +569,11 @@ may be specified before the body code:
        ,@(if local
              `((make-variable-buffer-local ',keymap)
                (put ',keymap 'permanent-local t)
-               (evil-add-to-alist 'evil-local-keymaps-alist
+               (evil--add-to-alist 'evil-local-keymaps-alist
                                   ',mode ',keymap))
-           `((evil-add-to-alist 'evil-global-keymaps-alist
+           `((evil--add-to-alist 'evil-global-keymaps-alist
                                 ',mode ',keymap)
-             (evil-add-to-alist 'evil-mode-map-alist
+             (evil--add-to-alist 'evil-mode-map-alist
                                 ',mode ,keymap)))
        ,(when (or body func)
           `(defun ,mode (&optional arg)
@@ -987,11 +988,12 @@ A return value of t means all states."
   (push '(t. localleader) unread-command-events))
 
 (defun evil-set-leader (state key &optional localleader)
-  "Set KEY to trigger <leader> bindings in STATE.
+  "Set KEY to trigger leader bindings in STATE.
 KEY should be in the form produced by `kbd'. STATE is one of
 `normal', `insert', `visual', `replace', `operator', `motion',
-`emacs', a list of one or more of these, or nil. nil means all of
-the above. If LOCAL is non-nil, set localleader instead."
+`emacs', a list of one or more of these, or `nil', which means
+all of the above. If LOCALLEADER is non-nil, set the local leader
+instead."
   (let* ((all-states '(normal insert visual replace operator motion emacs))
          (states (cond ((listp state) state)
                        ((member state all-states) (list state))
@@ -1004,20 +1006,19 @@ the above. If LOCAL is non-nil, set localleader instead."
 
 (defmacro evil-define-key (state keymap key def &rest bindings)
   "Create a STATE binding from KEY to DEF for KEYMAP.
-STATE is one of normal, insert, visual, replace, operator,
-motion, emacs, or a list of one or more of these. Omitting a
-state by using nil corresponds to a standard Emacs binding using
-`define-key'. The remaining arguments are like those of
-`define-key'. For example:
+STATE is one of `normal', `insert', `visual', `replace',
+`operator', `motion', `emacs', or a list of one or more of
+these. Omitting a state by using `nil' corresponds to a standard
+Emacs binding using `define-key'. The remaining arguments are
+like those of `define-key'. For example:
 
     (evil-define-key 'normal foo-map \"a\" 'bar)
 
-This creates a binding from \"a\" to bar in Normal state, which
-is active whenever foo-map is active. Using nil for the state,
+This creates a binding from `a' to `bar' in normal state, which
+is active whenever `foo-map' is active. Using nil for the state,
 the following lead to identical bindings:
 
     (evil-define-key nil foo-map \"a\" 'bar)
-
     (define-key foo-map \"a\" 'bar)
 
 It is possible to specify multiple states and/or bindings at
@@ -1027,21 +1028,20 @@ once:
       \"a\" 'bar
       \"b\" 'foo)
 
-If foo-map has not been initialized yet, this macro adds an entry
-to `after-load-functions', delaying execution as necessary.
+If `foo-map' has not been initialized yet, this macro adds an
+entry to `after-load-functions', delaying execution as necessary.
 
-KEYMAP may also be a quoted symbol. If the symbol is global, the
+KEYMAP may also be a quoted symbol. If the symbol is `global', the
 global evil keymap corresponding to the state(s) is used, meaning
 the following lead to identical bindings:
 
     (evil-define-key 'normal 'global \"a\" 'bar)
-
     (evil-global-set-key 'normal \"a\" 'bar)
 
-The symbol local may also be used, which corresponds to using
+The symbol `local' may also be used, which corresponds to using
 `evil-local-set-key'. If a quoted symbol is used that is not
-global or local, it is assumed to be the name of a minor mode, in
-which case `evil-define-minor-mode-key' is used."
+`global' or `local', it is assumed to be the name of a minor
+mode, in which case `evil-define-minor-mode-key' is used."
   (declare (indent defun))
   (cond ((member keymap '('global 'local))
          `(evil-define-key* ,state ,keymap ,key ,def ,@bindings))
@@ -1194,26 +1194,21 @@ Add additional BINDINGS if specified."
   "Define an Evil state STATE.
 DOC is a general description and shows up in all docstrings;
 the first line of the string should be the full name of the state.
-Then follows one or more optional keywords:
 
-:tag STRING             Mode line indicator.
-:message STRING         Echo area message when changing to STATE.
-:cursor SPEC            Cursor to use in STATE.
-:entry-hook LIST        Hooks run when changing to STATE.
-:exit-hook LIST         Hooks run when changing from STATE.
-:enable LIST            List of other states and modes enabled by STATE.
-:suppress-keymap FLAG   If FLAG is non-nil, makes `evil-suppress-map'
-                        the parent of the global map of STATE,
-                        effectively disabling bindings to
-                        `self-insert-command'.
+BODY is executed each time the state is enabled or disabled.
 
-Following the keywords is optional code to be executed each time
-the state is enabled or disabled. For example:
-
-    (evil-define-state test
-      \"Test state.\"
-      :tag \"<T> \"
-      (setq test-var t))
+Optional keyword arguments:
+- `:tag' - the mode line indicator, e.g. \"<T>\".
+- `:message' - string shown in the echo area when the state is
+  activated.
+- `:cursor' - default cursor specification.
+- `:enable' - list of other state keymaps to enable when in this
+  state.
+- `:entry-hook' - list of functions to run when entering this state.
+- `:exit-hook' - list of functions to run when exiting this state.
+- `:suppress-keymap' - if non-nil, effectively disables bindings to
+  `self-insert-command' by making `evil-suppress-map' the parent of
+  the global state keymap.
 
 The global keymap of this state will be `evil-test-state-map',
 the local keymap will be `evil-test-state-local-map', and so on.
@@ -1264,7 +1259,7 @@ the local keymap will be `evil-test-state-local-map', and so on.
        ((eq key :exit-hook)
         (setq exit-hook-value arg)
         (unless (listp exit-hook-value)
-          (setq exit-hook-value (list entry-hook-value))))
+          (setq exit-hook-value (list exit-hook-value))))
        ((eq key :enable)
         (setq enable arg))
        ((eq key :input-method)
@@ -1352,7 +1347,7 @@ If ARG is nil, don't display a message in the echo area.%s" name doc)
                  input-method-deactivate-hook)
              (evil-change-state nil)
              (setq evil-state ',state)
-             (evil-add-to-alist 'evil-previous-state-alist
+             (evil--add-to-alist 'evil-previous-state-alist
                                 ',state evil-previous-state)
              (let ((evil-state ',state))
                (evil-normalize-keymaps)
