@@ -1,9 +1,9 @@
-;;; evil-integration.el --- Integrate Evil with other modules
+;;; evil-integration.el --- Integrate Evil with other modules -*- lexical-binding: t -*-
 
 ;; Author: Vegard Øye <vegard_oye at hotmail.com>
 ;; Maintainer: Vegard Øye <vegard_oye at hotmail.com>
 
-;; Version: 1.12.17
+;; Version: 1.14.0
 
 ;;
 ;; This file is NOT part of GNU Emacs.
@@ -25,7 +25,6 @@
 ;; You should have received a copy of the GNU General Public License
 ;; along with Evil.  If not, see <http://www.gnu.org/licenses/>.
 
-
 ;;; Commentary:
 
 ;; This provides evil integration for various emacs modes.
@@ -291,6 +290,7 @@ activated."
 (declare-function ace-jump-char-mode "ext:ace-jump-mode")
 (declare-function ace-jump-word-mode "ext:ace-jump-mode")
 (declare-function ace-jump-line-mode "ext:ace-jump-mode")
+(defvar ace-jump-mode-scope)
 
 (defvar evil-ace-jump-active nil)
 
@@ -412,6 +412,7 @@ the mark and entering `recursive-edit'."
 (declare-function avy-goto-subword-0 "ext:avy")
 (declare-function avy-goto-subword-1 "ext:avy")
 (declare-function avy-goto-char-timer "ext:avy")
+(defvar avy-all-windows)
 
 (defmacro evil-enclose-avy-for-motion (&rest body)
   "Enclose avy to make it suitable for motions.
@@ -429,7 +430,7 @@ Based on `evil-enclose-ace-jump-for-motion'."
   (declare (indent defun)
            (debug t))
   (let ((name (intern (format "evil-%s" command))))
-    `(evil-define-motion ,name (_count)
+    `(evil-define-motion ,name (count)
        ,(format "Evil motion for `%s'." command)
        :type ,type
        :jump t
@@ -500,10 +501,8 @@ Based on `evil-enclose-ace-jump-for-motion'."
       (setq this-command #'digit-argument)
       (call-interactively #'digit-argument))
      (t
-      (let ((target (or (command-remapping #'evil-beginning-of-visual-line)
-                        #'evil-beginning-of-visual-line)))
-        (setq this-command 'evil-beginning-of-visual-line)
-        (call-interactively 'evil-beginning-of-visual-line)))))
+      (setq this-command 'evil-beginning-of-visual-line)
+      (call-interactively 'evil-beginning-of-visual-line))))
 
   (evil-define-minor-mode-key 'motion 'visual-line-mode
     "j" 'evil-next-visual-line
@@ -517,9 +516,12 @@ Based on `evil-enclose-ace-jump-for-motion'."
     "V" 'evil-visual-screen-line))
 
 ;;; abbrev.el
-(when evil-want-abbrev-expand-on-insert-exit
-  (eval-after-load 'abbrev
-    '(add-hook 'evil-insert-state-exit-hook 'expand-abbrev)))
+(defun evil-maybe-expand-abbrev ()
+  (when (and abbrev-mode evil-want-abbrev-expand-on-insert-exit)
+    (expand-abbrev)))
+
+(eval-after-load 'abbrev
+  '(add-hook 'evil-insert-state-exit-hook 'evil-maybe-expand-abbrev))
 
 ;;; ElDoc
 (eval-after-load 'eldoc
